## 0.13.2.2 (2022-11-14)

Comments explaining why `keyboard` and `tzlocal` are not run on multiple platforms (#9188)

## 0.13.2.1 (2022-11-03)

Update pyright to 1.1.278 (#9077)

Co-authored-by: Alex Waygood <Alex.Waygood@Gmail.com>

## 0.13.2 (2022-09-27)

Bump mypy to 0.981 (#8796)

## 0.13.1 (2022-09-22)

Add reportMissingParameterType to `pyrightconfig.stricter.json` (#8770)

## 0.13.0 (2022-09-06)

Added stubs for keyboard (#8666)

